@@ -1,6 +1,7 @@
 #! /usr/bin/env python
 # coding: utf-8
 
+import sys
 import six
 
 __author__ = '鹛桑够'
@@ -34,14 +35,27 @@ def is_string(s):
     return True
 
 
+def error_and_exit(msg, error_code=1):
+    sys.stderr.write(encode(msg))
+    sys.stderr.write("\n")
+    sys.exit(error_code)
+
 default_help_dict = dict(
     file_lost=dict(
         en="file [%s] not exist or can not readable",
         cn="文件[%s]不存在或者无权限读取"
     ),
+    dir_lost=dict(
+        en="directory [%s] not exist or can not readable",
+        cn="目录[%s]不存在或者无权限读取"
+    ),
     env_lost=dict(
         en="",
         cn=""
+    ),
+    debug=dict(
+        en=" Enter the debug mode,  print out as much information as possible.",
+        cn="进入debug模式尽可能多的打印出信息"
     )
 )
 
